@@ -20,7 +20,7 @@ def run_all_tests(username, password, live_port=None, historical_port=None, symb
         print(f'{Style.BRIGHT}{Fore.BLUE}Setting to default hist port = {DEFAULT_HIST_PORT}{Style.RESET_ALL}')
         historical_port = DEFAULT_HIST_PORT
     if symbols_to_test is None:
-        symbols_to_test = {['BANKNIFTY-I', 'NIFTY-I', 'CRUDEOIL-I']}
+        symbols_to_test = ['BANKNIFTY-I', 'NIFTY-I', 'CRUDEOIL-I']
 
     print(f'{Style.BRIGHT}{Fore.BLUE}Beginning connection test...{Style.RESET_ALL}')
     td_app = get_connection(username, password, live_port, historical_port)
